package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Feb 25, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func CopyTo(source, dest interface{}, debug ...bool) (err error)
CopyTo 将source结构体内容转换为dest结构体
Source Files
¶
Click to show internal directories.
Click to hide internal directories.